@@ -1,17 +1,17 @@
 #!/bin/bash
 
 chain_name=aembit-redirect-chain
-aembit_user_id=$(id --user aembit)
+aembit_group_id=$(id --group aembit_agent_proxy)
 agent_proxy_port=38080
 agent_dns_port=8053
 
 update-alternatives --set iptables /usr/sbin/iptables-legacy
 update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
 
-iptables -t raw -D OUTPUT -p udp --dport 53 -m owner --uid-owner "${aembit_user_id}" -j NOTRACK
+iptables -t raw -D OUTPUT -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j NOTRACK
 
 # Ignore (return to the main chain) all packets from our agent proxy
-iptables -t nat -D "${chain_name}" -m owner --uid-owner "${aembit_user_id}" -j RETURN
+iptables -t nat -D "${chain_name}" -m owner --uid-owner "${aembit_group_id}" -j RETURN
 
 # Ignore TCP loopback
 iptables -t nat -D "${chain_name}" -p tcp -o lo -j RETURN
